Name:           coq
Version:        8.16.1
Release:        %mkrel 1
Summary:        The Coq Proof Assistant
Group:          Sciences/Computer science
# The project as a whole is LGPL-2.1-only.  Exceptions:
# - clib/diff2.ml is MIT
# - gramlib is BSD-3-Clause
License:        LGPL-2.1-only AND MIT AND BSD-3-Clause
URL:            https://coq.inria.fr
Source0:        https://github.com/coq/coq/archive/V%{version}/%{name}-%{version}.tar.gz
Source2:        https://github.com/coq/coq/releases/download/V%{version}/coq-%{version}-reference-manual.pdf
# Sphinx documentation fails with sphinx 5+ (`language` must be set to
# an actual value, not `None`)
# https://github.com/coq/coq/pull/16310
Patch0:         16310.patch

BuildRequires:  ocaml-compiler
BuildRequires:  ocaml-compiler-libs
BuildRequires:  ocaml-dune >= 2.5.0
BuildRequires:  ocaml-findlib-devel >= 1.8.1
BuildRequires:  ocaml-lablgtk3-devel
BuildRequires:  ocaml-lablgtk3-sourceview3-devel
BuildRequires:  ocaml-ounit-devel
BuildRequires:  ocaml-zarith-devel >= 1.11
BuildRequires:  ocaml-zarith >= 1.11
BuildRequires:  antlr4
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  texlive
BuildRequires:  imagemagick
BuildRequires:  gtksourceview3-devel
BuildRequires:  libicns-utils
BuildRequires:  python3-devel
BuildRequires:  %{py3_dist antlr4-python3-runtime}
BuildRequires:  rsync
BuildRequires:  time

# For documentation
BuildRequires:  antlr4
BuildRequires:  hevea
# For latexmk:
BuildRequires:  texlive-collection-basic
BuildRequires:  python3-devel
BuildRequires:  python3-sphinx
BuildRequires:  python3-sphinx_rtd_theme

Requires:       ocaml-findlib

# Exclude private ocaml interfaces that we don't Provide
%global __requires_exclude ocamlx?\\\((Configwin_types|Interface|Richpp|Serialize|Xml_p(arser|rinter)|Xmlprotocol)\\\)

%description
Coq is a proof assistant which:
  - allows to handle calculus assertions,
  - check mechanically proofs of these assertions,
  - helps to find formal proofs,
  - extracts a certified program from the constructive proof
    of its formal specification.


%package ide
Summary:        The Coq Integrated Development Interface
Group:          Sciences/Computer science
Requires:       %{name} = %{version}
Requires:       %{name}-ide-server = %{version}

%description ide
The Coq Integrated Development Interface is a graphical interface for the
Coq proof assistant.


%package ide-server
Summary:        The coqidetop language server
Group:          Sciences/Computer science

%description ide-server
The Coq Integrated Development Interface is a graphical interface for the
Coq proof assistant.
This package provides the coqidetop language server, an implementation of	
Coq's XML protocol which allows clients, such as CoqIDE, to interact with	
Coq in a structured way.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation
License:        Open Publication License
BuildArch:      noarch
Requires:       font(fontawesome)
Requires:       font(lato)
Requires:       font(robotoslab)

%description doc
The %{name}-doc package contains documentation for %{name}.

%prep
%autosetup -p1

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Use our CFLAGS
sed -e 's|-Wall.*-O2|%{build_cflags} %{build_ldflags} -Wno-unused|' \
    -e 's| -march=native||' \
    -i tools/configure/configure.ml

# Make sure debuginfo is generated
sed -i 's,-shared,& -g,g' tools/CoqMakefile.in

# Do not invoke env
for f in doc/tools/coqrst/notations/fontsupport.py;
do
  sed -i.orig 's,/usr/bin/env python2,%{python3},' $f
  fixtimestamp $f
done
for f in $(grep -Frl '%{_bindir}/env'); do
  sed -r -i.orig 's,(%{_bindir}/)env[[:blank:]]+([[:alnum:]]+),\1\2,g' $f
  fixtimestamp $f
done

%build
%global coqdocdir %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/coq-%{version}}

# Regenerate ANTLR files
cd doc/tools/coqrst/notations
antlr4 -Dlanguage=Python3 -visitor -no-listener TacticNotations.g
cd -

%ifarch %{ocaml_native_compiler}
%global opt_option -native-compiler yes -coqide opt -bin-annot
%else
%global opt_option -byte-only -coqide byte
%endif
%ifarch %{ocaml_natdynlink}
%global opt_option %{opt_option} -natdynlink yes
%else
%global opt_option %{opt_option} -natdynlink no
%endif

# Set our configuration options
./configure -prefix %{_prefix}                       \
            -libdir %{ocamldir}/coq                  \
            -mandir %{_mandir}                       \
            -docdir %{coqdocdir}                     \
            -configdir %{_sysconfdir}/xdg/%{name}    \
            -bytecode-compiler yes                   \
            %{opt_option}                            \
            -browser "xdg-open %s"                   \
            -with-doc no

# Build the binary artifacts
export SPHINXWARNOPT="-w$PWD/sphinx-warn.log"
make world VERBOSE=1


%install
%make_install

# FIXME: why didn't this install in libdir?
mkdir -p %{buildroot}%{ocamldir}
mv %{buildroot}%{_prefix}/lib/{coq*,stublibs} %{buildroot}%{ocamldir}

# Install the LaTeX style file
# mkdir -p %{buildroot}%{_texmf_main}/tex/latex/misc
# mv %{buildroot}%{_datadir}/texmf/tex/latex/misc/coqdoc.sty \
#    %{buildroot}%{_texmf_main}/tex/latex/misc
# rm -fr %{buildroot}%{_datadir}/texmf

# FIXME: dune ignores the configdir argument to configure
mkdir -p %{buildroot}%{_sysconfdir}/xdg/%{name}

for png in 256x256 48x48 32x32 16x16; do
  mkdir -p %{buildroot}%{_iconsdir}/hicolor/${png}/apps/
  convert -geometry $png ide/coqide/%{name}.png %{buildroot}%{_iconsdir}/hicolor/${png}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_pkgdocdir}
install -Dpm644 %{SOURCE2} %{buildroot}%{_pkgdocdir}/

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=CoqIDE
Comment=Coq integrated developpment environment
Exec=%{_bindir}/coqide
Icon=coq
Type=Application
Categories=Education;Science;Math;
EOF


%files
%doc %{_pkgdocdir}/coq-core/README.md
%doc %{_pkgdocdir}/coq-core/LICENSE
%{_bindir}/*
%{_libdir}/ocaml/coq
%{ocamldir}/coq-core/
%{ocamldir}/stublibs/dllcoqrun_stubs.so
%{_mandir}/man1/*
%{_datadir}/%{name}/
%exclude %{_bindir}/coqide*
%{_datadir}/texmf/tex/latex/misc/coqdoc.sty

%files ide
%doc %{_pkgdocdir}/coqide/README.md
%doc %{_pkgdocdir}/coqide/LICENSE
%doc %{_pkgdocdir}/coqide/FAQ
%{_sysconfdir}/xdg/coq/
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_bindir}/coqide*
%{ocamldir}/coqide/

%files ide-server
%doc %{_pkgdocdir}/coqide-server/LICENSE
%doc %{_pkgdocdir}/coqide-server/README.md
%{_libdir}/ocaml/coqide-server/

%files doc
%doc %{_pkgdocdir}/coq-%{version}-reference-manual.pdf
%doc %{_pkgdocdir}/coqide/odoc-pages/index.mld


%changelog
* Sat Jan 07 2023 papoteur <papoteur> 8.16.1-1.mga9
+ Revision: 1931087
- Add ide-server
- fix file list
- new 8.16.1
- new 8.16.0
+ neoclust <neoclust>
- Rebuild against new ocaml
+ tv <tv>
- Updates BRs
- Fix install
+ pterjan <pterjan>
- Rebuild for new ocaml-lablgtk3

* Fri May 20 2022 pterjan <pterjan> 8.13.2-3.mga9
+ Revision: 1859409
- Rebuild for OCaml 4.14

* Fri Oct 15 2021 tv <tv> 8.13.2-2.mga9
+ Revision: 1751562
- Rebuild for ocaml 4.13.1

* Sun Sep 05 2021 wally <wally> 8.13.2-1.mga9
+ Revision: 1744351
- new version 8.13.2
- drop ancient tutorial docs

* Fri Mar 26 2021 tv <tv> 8.13.1-3.mga9
+ Revision: 1710447
- Disable doc (broken)
- rebuild for ocaml-4.2-12
+ neoclust <neoclust>
- Rebuild against new ocaml stack

* Mon Jan 11 2021 pterjan <pterjan> 8.11.0-4.mga8
+ Revision: 1671200
- Exclude more private modules
- Also exclude ocamlx requires when we exclude ocaml ones

* Sun Jan 10 2021 pterjan <pterjan> 8.11.0-2.mga8
+ Revision: 1670853
- Rebuild to generate ocamlx provides
+ tv <tv>
- remove one BR workaround which is now fixed

* Sun Mar 01 2020 tv <tv> 8.11.0-1.mga8
+ Revision: 1552552
- BR ocaml-cairo-devel (probably a missing dep of other BRs)
- BR ocaml-lablgtk3-sourceview3
+ pterjan <pterjan>
- Update to 8.11.0
+ umeabot <umeabot>
- Rebuild for ocaml 4.10.0 final

* Thu Feb 20 2020 umeabot <umeabot> 8.9.1-3.mga8
+ Revision: 1545296
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 tv <tv> 8.9.1-2.mga8
+ Revision: 1484376
- filter out a bogus requires on private ocaml interface
- consolidate exclude list

* Sun Jan 26 2020 tv <tv> 8.9.1-1.mga8
+ Revision: 1483034
- revert back to 8.9.1 & fix build
- new release + rebuild for ocaml-4.10
- new release + rebuild for ocaml-4.10
+ pterjan <pterjan>
- Rebuild for ocaml 4.07.1

* Wed Oct 24 2018 tv <tv> 8.7.1-1.mga7
+ Revision: 1325023
- new release
- rebuild with ocaml-4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 8.6.1-3.mga7
+ Revision: 1296798
- Mageia 7 Mass Rebuild

* Mon Dec 04 2017 tv <tv> 8.6.1-2.mga7
+ Revision: 1181263
- fix deps

* Mon Dec 04 2017 tv <tv> 8.6.1-1.mga7
+ Revision: 1181238
- new release
- add fixes from FC
- rebuild for new ocaml
+ shlomif <shlomif>
- New version 8.6 (requires new deps).

* Sun Sep 25 2016 pterjan <pterjan> 8.5pl2-2.mga6
+ Revision: 1056205
- Rebuild for fix in ocaml

* Sun Sep 18 2016 daviddavid <daviddavid> 8.5pl2-1.mga6
+ Revision: 1053630
- new version: 8.5pl2
- update URL and Sources URL
- exclude a private ocaml interface that we don't Provide, and a Provides that
  the automatic generator is failing to produce for ocaml-lablgtk
- add RecTutorial.pdf as a doc file
- update doc files and files list

* Tue Feb 02 2016 pterjan <pterjan> 8.4pl6-1.mga6
+ Revision: 930946
- Update to 8.4pl6

* Fri Sep 11 2015 neoclust <neoclust> 8.4pl4-7.mga6
+ Revision: 876969
- Enable debug

* Fri Sep 11 2015 neoclust <neoclust> 8.4pl4-6.mga6
+ Revision: 876939
- Fix build with new rpm ( empty debuginfo)

* Wed Oct 15 2014 umeabot <umeabot> 8.4pl4-5.mga5
+ Revision: 740302
- Second Mageia 5 Mass Rebuild

* Fri Sep 26 2014 tv <tv> 8.4pl4-4.mga5
+ Revision: 725007
- rebuild for bogus file deps

* Thu Sep 18 2014 umeabot <umeabot> 8.4pl4-3.mga5
+ Revision: 693686
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 8.4pl4-2.mga5
+ Revision: 678542
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 malo <malo> 8.4pl4-1.mga5
+ Revision: 638780
- update to 8.4pl4

* Sat Oct 19 2013 umeabot <umeabot> 8.4pl2-3.mga4
+ Revision: 527415
- Mageia 4 Mass Rebuild
+ luigiwalser <luigiwalser>
- fix check for make version

* Fri Jun 07 2013 malo <malo> 8.4pl2-1.mga4
+ Revision: 440012
- update to 8.4pl2 (patch from William Murphy)

* Mon Jan 14 2013 malo <malo> 8.4pl1-1.mga3
+ Revision: 387353
- new bugfix release 8.4pl1
- remove patch which was included upstream

* Fri Jan 11 2013 umeabot <umeabot> 8.4-3.mga3
+ Revision: 348157
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Oct 02 2012 blue_prawn <blue_prawn> 8.4-2.mga3
+ Revision: 302076
- build requires ocaml-compiler-libs
- rebuild with new ocaml 4.00
- also include documentation

* Sun Aug 26 2012 malo <malo> 8.4-1.mga3
+ Revision: 284166
- missing buildrequires on camlp4-devel
- update to version 8.4
- add patch from Gentoo for compatibility with lablgtk 2.16
- add desktop file for the IDE

* Sun Jul 29 2012 malo <malo> 8.3pl4-1.mga3
+ Revision: 275566
- new version 8.3pl4
- fix requires to ocaml-compiler

* Sat Jan 14 2012 malo <malo> 8.3pl3-1.mga2
+ Revision: 195965
- new version 8.3pl3

* Sun Oct 23 2011 malo <malo> 8.3pl2-1.mga2
+ Revision: 157538
- imported package coq


* Mon Jul 18 2011 Guillaume Rousse <guillomovitch@mandriva.org> 8.3pl2-1mdv2012.0
+ Revision: 690589
- new version

* Mon Dec 20 2010 Guillaume Rousse <guillomovitch@mandriva.org> 8.3-3mdv2011.0
+ Revision: 623284
- new version

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuild

* Wed Feb 10 2010 Guillaume Rousse <guillomovitch@mandriva.org> 8.2pl1-2mdv2010.1
+ Revision: 503738
- rebuild
- new version

* Mon Jun 29 2009 Guillaume Rousse <guillomovitch@mandriva.org> 8.2-2mdv2010.0
+ Revision: 390561
- rebuild for latest ocaml

* Wed Feb 18 2009 Guillaume Rousse <guillomovitch@mandriva.org> 8.2-1mdv2009.1
+ Revision: 342724
- final 8.2 version

* Sun Feb 15 2009 Guillaume Rousse <guillomovitch@mandriva.org> 8.2-0.rc2.1mdv2009.1
+ Revision: 340578
- new release

* Sun Aug 17 2008 Guillaume Rousse <guillomovitch@mandriva.org> 8.1pl3-1mdv2009.0
+ Revision: 272986
- new version

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Sep 28 2007 Guillaume Rousse <guillomovitch@mandriva.org> 8.1pl1-1mdv2008.0
+ Revision: 93431
- new version

  + Pascal Terjan <pterjan@mandriva.org>
    - Rebuild to sync with x86_64
    - Import coq



* Tue Aug 29 2006 Guillaume Rousse <guillomovitch@mandriva.org> 8.0pl3-5mdv2007.0
- Rebuild

* Mon Mar 27 2006 Guillaume Rousse <guillomovitch@mandriva.org> 8.0pl3-4mdk
- buildrequires

* Fri Mar 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 8.0pl3-3mdk
- disable stripping, as it breaks binaries

* Wed Mar 15 2006 Guillaume Rousse <guillomovitch@mandriva.org> 8.0pl3-2mdk
- add patch for ocaml 3.0.9
- buildrequires

* Thu Mar 02 2006 Guillaume Rousse <guillomovitch@mandriva.org> 8.0pl3-1mdk
- first mdk release
